@@ -34,6 +34,7 @@ class FieldTest(unittest.TestCase):
 #        self.test_only = ['test_Field___getitem__']
 #        self.test_only = ['test_Field_section']
 #        self.test_only = ['test_Field_expand_dims']
+#        self.test_only = ['test_Field_field']
 
     def test_Field_AUXILIARY_MASK(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -473,48 +474,48 @@ class FieldTest(unittest.TestCase):
         f.ncvar = 'tas'
         all_kwargs = (
             {'inverse': False},
-            {'inverse': False, 'select': None},
-            {'inverse': False, 'select': {}},
-            {'inverse': False, 'select': []},
-            {'inverse': False, 'select': [None]},
-            {'inverse': False, 'select': [{}]},
-            {'inverse': False, 'select': [None, {}]},
-            {'inverse': False, 'select':  'eastward_wind'},
-            {'inverse': False, 'select':  'eastward_wind', 'exact': True},
-            {'inverse': False, 'select':  'eastward_'},
-            {'inverse': False, 'select':  'e.*_wind$'},
-            {'inverse': False, 'select':  'standard_name:eastward_wind'},
-            {'inverse': False, 'select':  'standard_name:eastward_wind', 'exact': True},
-            {'inverse': False, 'select':  'standard_name:eastward_'},
-            {'inverse': False, 'select': {'standard_name': 'eastward_wind'}},
-            {'inverse': False, 'select': {'standard_name': 'eastward_'}},
-            {'inverse': False, 'select': cf.eq('.*_wind', exact=False)},
-            {'inverse': False, 'select':  'long_name:qwerty'},
-            {'inverse': False, 'select':  'long_name:qwerty', 'exact': True},
-            {'inverse': False, 'select':  'long_name:qwe'},
-            {'inverse': False, 'select': {'long_name': 'qwerty'}},
-            {'inverse': False, 'select': {'long_name': 'qwe'}},
-            {'inverse': False, 'select': {'long_name': cf.eq('qwerty')}},
-            {'inverse': False, 'select': {'long_name': cf.eq('qwe', exact=False)}},
-            {'inverse': False, 'select': 'ncvar%tas'},
-            {'inverse': False, 'select': 'ncvar%tas', 'exact': True},
-            {'inverse': False, 'select': 'ncvar%ta'},
-            {'inverse': False, 'select': {None: 'ncvar%.*as$'}},
-            {'inverse': False, 'select': {None: 'ncvar%tas$'}},
-            {'inverse': False, 'select': {None: 'ncvar%tas'}},
-            {'inverse': False, 'select': {None: 'ncvar%ta'}},
+            {'inverse': False, 'description': None},
+            {'inverse': False, 'description': {}},
+            {'inverse': False, 'description': []},
+            {'inverse': False, 'description': [None]},
+            {'inverse': False, 'description': [{}]},
+            {'inverse': False, 'description': [None, {}]},
+            {'inverse': False, 'description':  'eastward_wind'},
+            {'inverse': False, 'description':  'eastward_wind', 'exact': True},
+            {'inverse': False, 'description':  'eastward_'},
+            {'inverse': False, 'description':  'e.*_wind$'},
+            {'inverse': False, 'description':  'standard_name:eastward_wind'},
+            {'inverse': False, 'description':  'standard_name:eastward_wind', 'exact': True},
+            {'inverse': False, 'description':  'standard_name:eastward_'},
+            {'inverse': False, 'description': {'standard_name': 'eastward_wind'}},
+            {'inverse': False, 'description': {'standard_name': 'eastward_'}},
+            {'inverse': False, 'description': cf.eq('.*_wind', exact=False)},
+            {'inverse': False, 'description':  'long_name:qwerty'},
+            {'inverse': False, 'description':  'long_name:qwerty', 'exact': True},
+            {'inverse': False, 'description':  'long_name:qwe'},
+            {'inverse': False, 'description': {'long_name': 'qwerty'}},
+            {'inverse': False, 'description': {'long_name': 'qwe'}},
+            {'inverse': False, 'description': {'long_name': cf.eq('qwerty')}},
+            {'inverse': False, 'description': {'long_name': cf.eq('qwe', exact=False)}},
+            {'inverse': False, 'description': 'ncvar%tas'},
+            {'inverse': False, 'description': 'ncvar%tas', 'exact': True},
+            {'inverse': False, 'description': 'ncvar%ta'},
+            {'inverse': False, 'description': {None: 'ncvar%.*as$'}},
+            {'inverse': False, 'description': {None: 'ncvar%tas$'}},
+            {'inverse': False, 'description': {None: 'ncvar%tas'}},
+            {'inverse': False, 'description': {None: 'ncvar%ta'}},
             #          
-            {'inverse': False, 'select':  'eastward_wind', 'ndim': cf.wi(1, 3)},
-            {'inverse': False, 'select':  'BBB', 'ndim': cf.wi(1, 3), 'match_and': False},
-            {'inverse': False, 'select':  ['BBB', 'east'], 'ndim': cf.wi(1, 3), 'match_and': True},
+            {'inverse': False, 'description':  'eastward_wind', 'ndim': cf.wi(1, 3)},
+            {'inverse': False, 'description':  'BBB', 'ndim': cf.wi(1, 3), 'match_and': False},
+            {'inverse': False, 'description':  ['BBB', 'east'], 'ndim': cf.wi(1, 3), 'match_and': True},
             {'inverse': False, 'ndim': cf.wi(1, 3)},
         )
         for kwargs in all_kwargs:
             self.assertTrue(f.match(**kwargs), 
-                            'f.match(**%s) failed' % kwargs)
+                            'f.match(**{}) failed'.format(kwargs))
             kwargs['inverse'] = not kwargs['inverse']
             self.assertFalse(f.match(**kwargs),
-                             'f.match(**%s) failed' % kwargs)
+                             'f.match(**{}) failed'.format(kwargs))
         #--- End: for
     #--- End: def
 
@@ -690,7 +691,18 @@ class FieldTest(unittest.TestCase):
         f = cf.read(self.filename)[0]
         f.mask_invalid(i=True)
     #--- End: def
-        
+
+
+#    def test_Field_field(self):
+#        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+#            return
+#
+#        f = cf.read(self.filename)[0]
+#
+#        y = f.field('grid_lat')
+#        print y
+#    #--- End: def
+
 #--- End: class
 
 if __name__ == '__main__':
